@@ -14,23 +14,15 @@ from kuyruk.worker import Worker
 from kuyruk.events import EventMixin
 from kuyruk.connection import Connection
 
-__version__ = '0.20.3'
+__version__ = '0.21.0'
 __all__ = ['Kuyruk', 'Task', 'Worker']
 
-try:
-    # not available in python 2.6
-    from logging import NullHandler
-except ImportError:
-    class NullHandler(logging.Handler):
-        def emit(self, record):
-            pass
-
 
 logger = logging.getLogger(__name__)
 
 
 # Add NullHandler to prevent logging warnings on startup
-null_handler = NullHandler()
+null_handler = logging.NullHandler()
 logger.addHandler(null_handler)
 
 
@@ -79,7 +71,8 @@ class Kuyruk(EventMixin):
 
         :param queue: Queue name for the tasks.
         :param eager: Run task in process, do not use RabbitMQ.
-        :param retry: Retry this times before give up.
+        :param retry: Retry this times before give up. Task will be re-routed
+            and executed on another worker.
         :param task_class: Custom task class.
             Must be a subclass of :class:`~Task`.
             If this is :const:`None` then :attr:`Task.task_class` will be used.
