@@ -1,9 +1,9 @@
 import Queue
 from pprint import pformat
+from functools import total_ordering
 from SocketServer import ThreadingTCPServer, BaseRequestHandler
 
 from kuyruk.manager.messaging import message_loop
-from kuyruk.helpers.total_ordering import total_ordering
 
 
 class ManagerServer(ThreadingTCPServer):
